ExportServiceBase class abstract

Annotations
  • @GrpcServiceName.new('localizable.ExportService')

Constructors

ExportServiceBase()

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
createBackupForUser(ServiceCall call, UserId request) Stream<FileChunk>
createBackupForUser_Pre(ServiceCall $call, Future<UserId> $request) Stream<FileChunk>
createExportForProject(ServiceCall call, ProjectId request) Stream<FileChunk>
createExportForProject_Pre(ServiceCall $call, Future<ProjectId> $request) Stream<FileChunk>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited