GroupServiceBase class abstract

Annotations
  • @GrpcServiceName.new('localizable.GroupService')

Constructors

GroupServiceBase()

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
deleteGroup(ServiceCall call, GroupId request) Future<DeleteGroupResponse>
deleteGroup_Pre(ServiceCall $call, Future<GroupId> $request) Future<DeleteGroupResponse>
getGroup(ServiceCall call, GroupId request) Future<Group>
getGroup_Pre(ServiceCall $call, Future<GroupId> $request) Future<Group>
getGroupsByUser(ServiceCall call, UserId request) Future<GroupList>
getGroupsByUser_Pre(ServiceCall $call, Future<UserId> $request) Future<GroupList>
getPrimaryGroup(ServiceCall call, Empty request) Future<Group>
getPrimaryGroup_Pre(ServiceCall $call, Future<Empty> $request) Future<Group>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
upsertGroup(ServiceCall call, Group request) Future<Group>
upsertGroup_Pre(ServiceCall $call, Future<Group> $request) Future<Group>

Operators

operator ==(Object other) bool
The equality operator.
inherited