LocaleServiceBase class abstract

Annotations
  • @GrpcServiceName.new('localizable.LocaleService')

Constructors

LocaleServiceBase()

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
getLocale(ServiceCall call, LocaleId request) Future<Locale>
getLocale_Pre(ServiceCall $call, Future<LocaleId> $request) Future<Locale>
getLocales(ServiceCall call, Empty request) Future<LocaleList>
getLocales_Pre(ServiceCall $call, Future<Empty> $request) Future<LocaleList>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited