ProjectServiceBase class abstract

Annotations
  • @GrpcServiceName.new('localizable.ProjectService')

Constructors

ProjectServiceBase()

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
deleteProject(ServiceCall call, ProjectId request) Future<DeleteProjectResponse>
deleteProject_Pre(ServiceCall call, Future<ProjectId> request) Future<DeleteProjectResponse>
getAllProjects(ServiceCall call, Empty request) Future<ProjectList>
getAllProjects_Pre(ServiceCall call, Future<Empty> request) Future<ProjectList>
getProject(ServiceCall call, ProjectId request) Future<Project>
getProject_Pre(ServiceCall call, Future<ProjectId> request) Future<Project>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
upsertProject(ServiceCall call, Project request) Future<Project>
upsertProject_Pre(ServiceCall call, Future<Project> request) Future<Project>

Operators

operator ==(Object other) bool
The equality operator.
inherited