copyWith method

  1. @Deprecated('See https://github.com/google/protobuf.dart/issues/998.')
TResult copyWith(
  1. void updates(
    1. TResult
    )
)

Apply updates to a copy of this message.

Makes a writable shallow copy of this message, applies the updates to it, and marks the copy read-only before returning it.

Implementation

@$core.Deprecated('See https://github.com/google/protobuf.dart/issues/998.')
TResult copyWith(void Function(TResult) updates) =>
    super.copyWith((message) => updates(message as TResult)) as TResult;