TranslateServiceBase class abstract

Annotations
  • @GrpcServiceName.new('localizable.TranslateService')

Constructors

TranslateServiceBase()

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
translate(ServiceCall call, TextTranslate request) Future<TResult>
translate_Pre(ServiceCall $call, Future<TextTranslate> $request) Future<TResult>

Operators

operator ==(Object other) bool
The equality operator.
inherited