TranslationServiceBase class abstract

Annotations
  • @GrpcServiceName.new('localizable.TranslationService')

Constructors

TranslationServiceBase()

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
copyTranslation(ServiceCall call, CopyTranslationRequest request) Future<Translation>
copyTranslation_Pre(ServiceCall $call, Future<CopyTranslationRequest> $request) Future<Translation>
deleteTranslation(ServiceCall call, TranslationId request) Future<DeleteTranslationResponse>
deleteTranslation_Pre(ServiceCall $call, Future<TranslationId> $request) Future<DeleteTranslationResponse>
getTranslation(ServiceCall call, TranslationId request) Future<Translation>
getTranslation_Pre(ServiceCall $call, Future<TranslationId> $request) Future<Translation>
getTranslationsByProject(ServiceCall call, ProjectId request) Future<TranslationList>
getTranslationsByProject_Pre(ServiceCall $call, Future<ProjectId> $request) Future<TranslationList>
getTranslationsByProjectSearch(ServiceCall call, ProjectSearch request) Future<TranslationList>
getTranslationsByProjectSearch_Pre(ServiceCall $call, Future<ProjectSearch> $request) Future<TranslationList>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
upsertTranslation(ServiceCall call, Translation request) Future<Translation>
upsertTranslation_Pre(ServiceCall $call, Future<Translation> $request) Future<Translation>

Operators

operator ==(Object other) bool
The equality operator.
inherited