TranslationServiceClient class
- Annotations
-
- @GrpcServiceName.new('localizable.TranslationService')
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options})
→ ClientCall<Q, R>
-
inherited
-
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options})
→ ResponseStream<R>
-
inherited
-
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options})
→ ResponseFuture<R>
-
inherited
-
copyTranslation(CopyTranslationRequest request, {CallOptions? options})
→ ResponseFuture<Translation>
-
-
deleteTranslation(TranslationId request, {CallOptions? options})
→ ResponseFuture<DeleteTranslationResponse>
-
-
getTranslation(TranslationId request, {CallOptions? options})
→ ResponseFuture<Translation>
-
-
getTranslationsByProject(ProjectId request, {CallOptions? options})
→ ResponseFuture<TranslationList>
-
-
getTranslationsByProjectSearch(ProjectSearch request, {CallOptions? options})
→ ResponseFuture<TranslationList>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
upsertTranslation(Translation request, {CallOptions? options})
→ ResponseFuture<Translation>
-