TranslationLocalizationServiceClient class

Annotations
  • @GrpcServiceName.new('localizable.TranslationLocalizationService')

Constructors

TranslationLocalizationServiceClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R>
inherited
deleteTranslationLocalization(TranslationLocalizationId request, {CallOptions? options}) → ResponseFuture<DeleteTranslationLocalizationResponse>
getTranslationLocalization(TranslationLocalizationId request, {CallOptions? options}) → ResponseFuture<TranslationLocalization>
getTranslationLocalizationByTranslationLocaleAndVariant(TranslationLocaleAndVariant request, {CallOptions? options}) → ResponseFuture<TranslationLocalization>
getTranslationLocalizationsByTranslation(TranslationId request, {CallOptions? options}) → ResponseFuture<TranslationLocalizationList>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
upsertTranslationLocalization(TranslationLocalization request, {CallOptions? options}) → ResponseFuture<TranslationLocalization>
upsertTranslationLocalizations(TranslationLocalizationList request, {CallOptions? options}) → ResponseFuture<TranslationLocalizationList>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultHost → const String
The hostname for this service.
oauthScopes → const List<String>
OAuth scopes needed for the client.