VariableServiceBase class abstract

Annotations
  • @GrpcServiceName.new('localizable.VariableService')

Constructors

VariableServiceBase()

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
deleteVariable(ServiceCall call, VariableId request) Future<DeleteVariableResponse>
deleteVariable_Pre(ServiceCall $call, Future<VariableId> $request) Future<DeleteVariableResponse>
getVariable(ServiceCall call, VariableId request) Future<Variable>
getVariable_Pre(ServiceCall $call, Future<VariableId> $request) Future<Variable>
getVariablesByTranslation(ServiceCall call, TranslationId request) Future<VariableList>
getVariablesByTranslation_Pre(ServiceCall $call, Future<TranslationId> $request) Future<VariableList>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
upsertVariable(ServiceCall call, Variable request) Future<Variable>
upsertVariable_Pre(ServiceCall $call, Future<Variable> $request) Future<Variable>

Operators

operator ==(Object other) bool
The equality operator.
inherited