VariableLocalizationServiceBase class abstract

Annotations
  • @GrpcServiceName.new('localizable.VariableLocalizationService')

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
deleteVariableLocalization(ServiceCall call, VariableLocalizationId request) Future<DeleteVariableLocalizationResponse>
deleteVariableLocalization_Pre(ServiceCall $call, Future<VariableLocalizationId> $request) Future<DeleteVariableLocalizationResponse>
getVariableLocalization(ServiceCall call, VariableLocalizationId request) Future<VariableLocalization>
getVariableLocalization_Pre(ServiceCall $call, Future<VariableLocalizationId> $request) Future<VariableLocalization>
getVariableLocalizationByVariableLocaleTypeAndVariant(ServiceCall call, VariableLocaleTypeAndVariant request) Future<VariableLocalization>
getVariableLocalizationByVariableLocaleTypeAndVariant_Pre(ServiceCall $call, Future<VariableLocaleTypeAndVariant> $request) Future<VariableLocalization>
getVariableLocalizationsByVariable(ServiceCall call, VariableId request) Future<VariableLocalizationList>
getVariableLocalizationsByVariable_Pre(ServiceCall $call, Future<VariableId> $request) Future<VariableLocalizationList>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
upsertVariableLocalization(ServiceCall call, VariableLocalization request) Future<VariableLocalization>
upsertVariableLocalization_Pre(ServiceCall $call, Future<VariableLocalization> $request) Future<VariableLocalization>
upsertVariableLocalizations(ServiceCall call, VariableLocalizationList request) Future<VariableLocalizationList>
upsertVariableLocalizations_Pre(ServiceCall $call, Future<VariableLocalizationList> $request) Future<VariableLocalizationList>

Operators

operator ==(Object other) bool
The equality operator.
inherited