ConfigNotifier class

Constructors

ConfigNotifier()

Properties

config Config
no getter
hashCode int
The hash code for this object.
no setterinherited
ref → Ref
The Ref associated with this notifier.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state Config
The value currently exposed by this notifier.
getter/setter pairinherited
stateOrNull Config?
The value currently exposed by this Notifier.
no setterinherited

Methods

build() Config
Initialize a Notifier.
listenSelf(void listener(Config? previous, Config next), {void onError(Object error, StackTrace stackTrace)?}) → RemoveListener
Listens to changes on the value exposed by this provider.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
runBuild() → void
Executes Notifier.build.
inherited
toString() String
A string representation of this object.
inherited
updateShouldNotify(Config previous, Config next) bool
A method invoked when the state exposed by this Notifier changes. It compares the previous and new value, and return whether listeners should be notified.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited