ExportService class

Constructors

ExportService(ExportServiceClient _exportServiceClient, ProjectService _projectService, String token)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String
final

Methods

createExportByProject(String projectId) Future<Export>
getExportById(String id) Future<Export>
getLatestExportByProject(String projectId) Future<Export>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
waitForExportProcessing(String projectId) Future<Export>

Operators

operator ==(Object other) bool
The equality operator.
inherited