VersionCheckService class

Constructors

VersionCheckService({String packageName = 'intl_localizable', String currentVersion = packageVersion, Duration checkInterval = const Duration(days: 1), String baseUrl = 'https://pub.dev', HttpClient? httpClient, File? cacheFile})

Properties

baseUrl String
final
cacheFile File?
final
checkInterval Duration
final
currentVersion String
final
hashCode int
The hash code for this object.
no setterinherited
httpClient HttpClient?
final
packageName String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkForUpdates({void printMessage(String message)?}) Future<void>
checkUpdateMessage() Future<String?>
getLatestVersion({bool forceRefresh = false}) Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited