LocalizableBaseCommand class abstract

Inheritance
Implementers

Constructors

LocalizableBaseCommand()

Properties

aliases List<String>
Alternate names for this command.
no setterinherited
argParser → ArgParser
The argument parser for this command.
no setterinherited
argResults → ArgResults?
The parsed argument results for this command.
no setterinherited
category String
The command's category.
no setterinherited
description String
A description of this command, included in usage.
no setterinherited
explicitProjectConfig String?
no setter
explicitProjectId String?
no setter
explicitProjectKey String?
no setter
explicitUserConfig String?
no setter
explicitUserKey String?
no setter
globalResults → ArgResults?
The parsed global argument results.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hidden bool
Whether or not this command should be hidden from help listings.
no setterinherited
inputPath String
no setter
invocation String
A single-line template for how to invoke this command (e.g. "pub get package").
no setterinherited
isJsonOutput bool
no setter
name String
The name of this command.
no setterinherited
parent → Command<int>?
The command's parent command, if this is a subcommand.
no setterinherited
projectConfig ProjectConfig?
no setter
resolvedProjectId String?
no setter
runner → CommandRunner<int>?
The command runner for this command.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subcommands Map<String, Command<int>>
An unmodifiable view of all sublevel commands of this command.
no setterinherited
suggestionAliases List<String>
Alternate non-functional names for this command.
no setterinherited
summary String
A short description of this command, included in parent's CommandRunner.usage.
no setterinherited
takesArguments bool
Whether or not this command takes positional arguments in addition to options.
no setterinherited
usage String
Generates a string displaying usage information for this command.
no setterinherited
usageFooter String?
An optional footer for usage.
no setterinherited
userConfig UserConfig?
no setter

Methods

addSubcommand(Command<int> command) → void
Adds Command as a subcommand of this.
inherited
getCallOptions({bool requireUser = true}) → CallOptions
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printError(Object error) → void
printOutput(Object? data) → void
printUsage() → void
Prints the usage information for this command.
inherited
requireAnyAuthToken() String
requireProjectId() String
requireProjectIdAsync() Future<String>
requireUserToken() String
run() FutureOr<int>?
Runs this command.
inherited
toString() String
A string representation of this object.
inherited
usageException(String message) → Never
Throws a UsageException with message.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited